@@ -1,20 +1,21 @@
 # pylint: disable=unidiomatic-typecheck
 
 import json
-
 from collections import defaultdict
+
 from d3rlpy.gpu import get_gpu_count
 from flask import Blueprint, jsonify
+
 from ..models.experiment import Experiment, ExperimentSchema
 from .project import _process_metrics
 
-system_route = Blueprint('system', __name__)
+system_route = Blueprint("system", __name__)
 
 
 def _get_device_id_and_data(experiment):
     # identify device
     config = json.loads(experiment.config)
-    device_id = config['use_gpu'] if 'use_gpu' in config else None
+    device_id = config["use_gpu"] if "use_gpu" in config else None
 
     # make response data
     data = ExperimentSchema().dump(experiment)
@@ -24,7 +25,7 @@ def _get_device_id_and_data(experiment):
     return device_id, data
 
 
-@system_route.route('/status', methods=['GET'])
+@system_route.route("/status", methods=["GET"])
 def get_system_status():
     n_gpus = get_gpu_count()
 
@@ -41,13 +42,8 @@ def get_system_status():
             cpu_jobs.append(data)
 
     res = {
-        'gpu': {
-            'total': n_gpus,
-            'jobs': gpu_jobs
-        },
-        'cpu': {
-            'jobs': cpu_jobs
-        }
+        "gpu": {"total": n_gpus, "jobs": gpu_jobs},
+        "cpu": {"jobs": cpu_jobs},
     }
 
     return jsonify(res)
