@@ -1,16 +1,17 @@
 # pylint: disable=no-member, no-self-use
 
 from datetime import datetime
+
 from werkzeug.exceptions import NotFound
+
 from ..database import db
 
 
 class BaseModel:
     created_at = db.Column(db.DateTime, nullable=True, default=datetime.now)
-    updated_at = db.Column(db.DateTime,
-                           nullable=True,
-                           default=datetime.now,
-                           onupdate=datetime.now)
+    updated_at = db.Column(
+        db.DateTime, nullable=True, default=datetime.now, onupdate=datetime.now
+    )
 
     def delete(self):
         db.session.delete(self)
